@@ -114,9 +114,9 @@ class KMeans:
       max_sim_v, max_sim_i = sim.max(dim=-1)
       return max_sim_v, max_sim_i
     else:
-      if x.dtype == torch.float:
+      if a.dtype == torch.float:
         expected = a.shape[0] * a.shape[1] * b.shape[0] * 4
-      elif x.dtype == torch.half:
+      elif a.dtype == torch.half:
         expected = a.shape[0] * a.shape[1] * b.shape[0] * 2
       ratio = math.ceil(expected / self.remaining_memory())
       subbatch_size = math.ceil(batch_size / ratio)
